@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Vishesh Yadav <vishesh3y@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Vishesh Yadav <vishesh3y@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ignorewidget.h"
 #include "../hgwrapper.h"
@@ -80,7 +67,7 @@ void HgIgnoreWidget::setupUntrackedList()
     QString output;
     hgw->executeCommand(QLatin1String("status"), args, output);
     
-    const QStringList result = output.split('\n', QString::SkipEmptyParts);
+    const QStringList result = output.split('\n', Qt::SkipEmptyParts);
     for (const QString &file : result) {
         m_untrackedList->addItem(file.mid(2));
     }
@@ -155,7 +142,7 @@ void HgIgnoreWidget::slotRemoveEntries()
 }
 void HgIgnoreWidget::slotEditEntry()
 {
-    if (m_ignoreTable->currentItem() == 0) {
+    if (m_ignoreTable->currentItem() == nullptr) {
         KMessageBox::error(this, xi18nc("@message:error",
                     "No entry selected for edit!"));
         return;
